@@ -18,14 +18,14 @@ from .utils import (
 )
 
 
-__version__ = '1.3.13'
+__version__ = '1.4.2'
 
 
 versioning_manager = VersioningManager()
 
 
 def make_versioned(
-    mapper=sa.orm.mapper,
+    mapper=sa.orm.Mapper,
     session=sa.orm.session.Session,
     manager=versioning_manager,
     plugins=None,
@@ -66,7 +66,7 @@ def make_versioned(
 
     sa.event.listen(
         sa.engine.Engine,
-        'before_cursor_execute',
+        'before_execute',
         manager.track_association_operations
     )
 
@@ -84,7 +84,7 @@ def make_versioned(
 
 
 def remove_versioning(
-    mapper=sa.orm.mapper,
+    mapper=sa.orm.Mapper,
     session=sa.orm.session.Session,
     manager=versioning_manager
 ):
@@ -105,7 +105,7 @@ def remove_versioning(
     manager.remove_session_tracking(session)
     sa.event.remove(
         sa.engine.Engine,
-        'before_cursor_execute',
+        'before_execute',
         manager.track_association_operations
     )
 
