@@ -14,7 +14,7 @@ def get_end_tx_column_query(
     primary_keys = [c.name for c in table.c if c.primary_key]
 
     tx_criterion = sa.select(
-        [sa.func.min(getattr(v3.c, tx_column_name))]
+        sa.func.min(getattr(v3.c, tx_column_name))
     ).where(
         sa.and_(
             getattr(v3.c, tx_column_name) > getattr(v1.c, tx_column_name),
@@ -25,18 +25,16 @@ def get_end_tx_column_query(
             ]
         )
     )
-    try:
-        tx_criterion = tx_criterion.scalar_subquery()
-    except AttributeError:  # SQLAlchemy < 1.4
-        tx_criterion = tx_criterion.as_scalar()
-    return sa.select(
-        columns=[
-            getattr(v1.c, column)
-            for column in primary_keys
-        ] + [
-            getattr(v2.c, tx_column_name).label(end_tx_column_name)
-        ],
-        from_obj=v1.outerjoin(
+    tx_criterion = tx_criterion.scalar_subquery()
+
+    columns = [
+        getattr(v1.c, column)
+        for column in primary_keys
+    ]
+    columns += [getattr(v2.c, tx_column_name).label(end_tx_column_name)]
+
+    return sa.select(*columns).select_from(
+        v1.outerjoin(
             v2,
             sa.and_(
                 getattr(v2.c, tx_column_name) ==
@@ -78,19 +76,19 @@ def update_end_tx_column(
         end_tx_column_name=end_tx_column_name,
         tx_column_name=tx_column_name
     )
-    stmt = conn.execute(query)
+    result = conn.execute(query)
     primary_keys = [c.name for c in table.c if c.primary_key]
-    for row in stmt:
-        if row[end_tx_column_name]:
+    for row in result:
+        if getattr(row, end_tx_column_name):
             criteria = [
-                getattr(table.c, pk) == row[pk]
+                getattr(table.c, pk) == getattr(row, pk)
                 for pk in primary_keys
             ]
 
             update_stmt = (
                 table.update()
                 .where(sa.and_(*criteria))
-                .values({end_tx_column_name: row[end_tx_column_name]})
+                .values({end_tx_column_name: getattr(row, end_tx_column_name)})
             )
             conn.execute(update_stmt)
 
@@ -106,18 +104,19 @@ def get_property_mod_flags_query(
     v2 = sa.alias(table, name='v2')
     primary_keys = [c.name for c in table.c if c.primary_key]
 
-    return sa.select(
-        columns=[
-            getattr(v1.c, column)
-            for column in primary_keys
-        ] + [
-            (sa.or_(
-                getattr(v1.c, column) != getattr(v2.c, column),
-                getattr(v2.c, tx_column_name).is_(None)
-            )).label(column + mod_suffix)
-            for column in tracked_columns
-        ],
-        from_obj=v1.outerjoin(
+    columns = [
+        getattr(v1.c, column)
+        for column in primary_keys
+    ]
+    columns += [
+        (sa.or_(
+            getattr(v1.c, column) != getattr(v2.c, column),
+            getattr(v2.c, tx_column_name).is_(None)
+        )).label(column + mod_suffix)
+        for column in tracked_columns
+    ]
+    return sa.select(*columns).select_from(
+        v1.outerjoin(
             v2,
             sa.and_(
                 getattr(v2.c, end_tx_column_name) ==
@@ -169,18 +168,18 @@ def update_property_mod_flags(
         end_tx_column_name=end_tx_column_name,
         tx_column_name=tx_column_name,
     )
-    stmt = conn.execute(query)
+    result = conn.execute(query)
 
     primary_keys = [c.name for c in table.c if c.primary_key]
-    for row in stmt:
+    for row in result:
         values = dict([
-            (column + mod_suffix, row[column + mod_suffix])
+            (column + mod_suffix, getattr(row, column + mod_suffix))
             for column in tracked_columns
-            if row[column + mod_suffix]
+            if getattr(row, column + mod_suffix)
         ])
         if values:
             criteria = [
-                getattr(table.c, pk) == row[pk] for pk in primary_keys
+                getattr(table.c, pk) == getattr(row, pk) for pk in primary_keys
             ]
             query = table.update().where(sa.and_(*criteria)).values(values)
             conn.execute(query)
